{% extends "base.html" %}

{% block content %}
<form action="" method="post">{% csrf_token %}
    <p>Are you sure you want to delete "{{ object }}"?</p>
    <input type="hidden" name="target_url" value="{{target_url}}">
    <input type="submit" value="Confirm" />
</form>
{% endblock %}
